# Table of Contents

- [fact-sheet-subtype-management](<./fact-sheet-subtype-management.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Fact Sheet Subtype Management](<./Fact-Sheet-Subtype-Management.md>)
  - [Overview](<./Fact-Sheet-Subtype-Management/Overview.md>)
  - [Creating Custom Fact Sheet Subtypes](<./Fact-Sheet-Subtype-Management/Creating-Custom-Fact-Sheet-Subtypes.md>)
  - [Creating Attributes Specific to Subtypes](<./Fact-Sheet-Subtype-Management/Creating-Attributes-Specific-to-Subtypes.md>)
  - [Limiting Existing Attributes to Specific Subtypes](<./Fact-Sheet-Subtype-Management/Limiting-Existing-Attributes-to-Specific-Subtypes.md>)
  - [Scope of Subtype Management](<./Fact-Sheet-Subtype-Management/Scope-of-Subtype-Management.md>)
